#python-utils
Common python utilities, currently for Build scripts

## pykrete
Python package for import in Build scripts:  
pykrete  
|-- args - argument types verifiers  
|-- builder - build management  
| . |-- info - build information  
| . |-- manager - build managers  
|-- calls - shell calls  
|-- distrib - distutils commands  
| . |-- pylint - pylint commands  
|-- packages - package management  
|-- versioning - version management
